@@ -494,8 +494,12 @@ modSAtree <- function(SApopdatlst = NULL,
   ## Define empty lists
   estlst <- list()
   predselectlst <- list()
-  predselectlst.unit <- list()
-  predselectlst.area <- list()
+  if (multest || SAmethod == "unit") {
+    predselectlst.unit <- list()
+  }
+  if (multest || SAmethod == "area") {
+    predselectlst.area <- list()
+  }
   SAobjlst <- list()
   dunitareabind <- {}
   if (addSAdomsdf) {
@@ -508,15 +512,20 @@ modSAtree <- function(SApopdatlst = NULL,
 
   if (!is.null(rowvar)) {
     estlst_row <- list()
-    predselectlst_row <- list()
-    SAobjslt_row <- list()
+    if (multest || SAmethod == "unit") {
+      predselectlst.unit_row <- list()
+    }
+    if (multest || SAmethod == "area") {
+      predselectlst.area_row <- list()
+    }
+    SAobjlst_row <- list()
     if (save4testing) {
       pdomdatlst_row <- list()
       dunitlutlst_row <- list()
     }
   }
 
-
+  largebnd.unique2 <- largebnd.unique
   for (i in 1:length(SApopdatlst)) {
     SApopdatnm <- names(SApopdatlst)[i]
     if (is.null(SApopdatnm)) {
@@ -732,25 +741,22 @@ modSAtree <- function(SApopdatlst = NULL,
 
     ## check largebnd.unique
     ########################################################
-    if (!is.null(largebnd.unique) && !is.null(SAdomsdf)) {
+    if (!is.null(largebnd.unique2) && !is.null(SAdomsdf)) {
       cdomdat <- merge(cdomdat, 
 		        unique(setDT(SAdomsdf)[, c(smallbnd.dom, largebnd.unique), with=FALSE]),
  		        by=smallbnd.dom)
       #addSAdomsdf <- TRUE
       #SAdomvars <- unique(c(SAdomvars, largebnd.unique))
-      lunique <- largebnd.unique
+      largebnd.unique <- largebnd.unique2
     } else {
       cdomdat$LARGEBND <- 1
-      lunique <- "LARGEBND"
       largebnd.unique <- "LARGEBND"
+      cdomdat$LARGEBND <- 1
     }
-    cdomdat$LARGEBND <- 1
-    lunique <- "LARGEBND"
 
     ## get unique largebnd values
-    largebnd.vals <- sort(unique(cdomdat[[lunique]]))
-    largebnd.vals <- largebnd.vals[table(cdomdat[[lunique]]) > 30]
-
+    largebnd.vals <- sort(unique(cdomdat[[largebnd.unique]]))
+    largebnd.vals <- largebnd.vals[table(cdomdat[[largebnd.unique]]) > 30]
 
     ## Add AOI if not in data
     ######################################
@@ -763,7 +769,7 @@ modSAtree <- function(SApopdatlst = NULL,
     ######################################
     ## Sum estvar.name by dunitvar (DOMAIN), plot, domain
     tdomdattot <- setDT(cdomdat)[, lapply(.SD, sum, na.rm=TRUE), 
-		                by=c(lunique, dunitvar, "AOI", cuniqueid, "TOTAL", prednames), 
+		                by=c(largebnd.unique, dunitvar, "AOI", cuniqueid, "TOTAL", prednames), 
 		                .SDcols=estvar.name]
 
     ## get estimate by domain, by largebnd value
@@ -792,7 +798,7 @@ modSAtree <- function(SApopdatlst = NULL,
 	tryCatch(
 		lapply(largebnd.vals, SAest.large, 
 			      dat=tdomdattot, 
-		       cuniqueid=cuniqueid, largebnd.unique=lunique, 
+		       cuniqueid=cuniqueid, largebnd.unique=largebnd.unique, 
 		       dunitlut=dunitlut, dunitvar="DOMAIN", 
 		       prednames=prednames, domain="TOTAL", response=response, 
 		       showsteps=showsteps, savesteps=savesteps, 
@@ -862,7 +868,7 @@ modSAtree <- function(SApopdatlst = NULL,
 
     if (rowcolinfo$rowvar != "TOTAL") {
       cdomdatsum <- setDT(cdomdat)[, lapply(.SD, sum, na.rm=TRUE), 
-                      by=c(lunique, dunitvar, cuniqueid, 
+                      by=c(largebnd.unique, dunitvar, cuniqueid, 
                            rowcolinfo$rowvar, prednames), .SDcols=estvar.name]
 
       if (!"DOMAIN" %in% names(cdomdatsum)) {
@@ -883,7 +889,7 @@ modSAtree <- function(SApopdatlst = NULL,
 		tryCatch(
 			lapply(largebnd.vals, SAest.large, 
 				dat=cdomdatsum, cuniqueid=cuniqueid, 
-				largebnd.unique=lunique, dunitlut=dunitlut, dunitvar="DOMAIN",
+				largebnd.unique=largebnd.unique, dunitlut=dunitlut, dunitvar="DOMAIN",
 				prednames=prednames, domain=rowcolinfo$rowvar,
 				response=response, showsteps=showsteps, savesteps=savesteps,
 				stepfolder=stepfolder, prior=prior, modelselect=modelselect,
@@ -1162,6 +1168,7 @@ modSAtree <- function(SApopdatlst = NULL,
   ## Append name of package and method to outfile name
   outfn.estpse2 <- paste0(outfn.estpse, "_modSA_", SApackage, "_", SAmethod) 
 
+
   ###################################################################################
   ## GENERATE OUTPUT TABLES
   ###################################################################################
@@ -1190,6 +1197,7 @@ modSAtree <- function(SApopdatlst = NULL,
 #      est2return[is.na(est2return$"Percent Sampling Error"), 
 #		"Percent Sampling Error"] <- psenull 
 #    }
+
     returnlst$est <- est2return
 #  } 
   if (!is.null(pse2return)) {
